pub enum PgsPcsCompositionState {
EpochStart,
AcquisitionPoint,
Normal,
}Expand description
Enum representing the composition state of a PCS. The composition state describes whether the segment starts a new display, refreshes an existing display, or updates a display.
Variants