PgsRead

Trait PgsRead 

pub trait PgsRead: Read + PgsSeek { }
A trait for reading data with seeking capabilities.

This trait combines Read from the standard library and PgsSeek, indicating that a type implementing this trait can both read data and seek within it.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors